@@ -203,13 +203,13 @@ class LinuxDevice(object):
             # It's a bug workaround for the issues/669:
             # https://github.com/pexpect/pexpect/issues/669
             LinuxDevice.cmd(self,
-                'echo "set enable-bracketed-paste off" > .workaround_for_pexpect_issue669',
-                log_level = self.LOG_CRIT)
+                'echo "set enable-bracketed-paste off" > .netdevice_workaround_for_pexpect_issue669',
+                log_level = self.LOG_WARNING)
             LinuxDevice.cmd(self,
-                    'export INPUTRC=$PWD/.workaround_for_pexpect_issue669',
-                    log_level = self.LOG_CRIT)
+                    'export INPUTRC=$PWD/.netdevice_workaround_for_pexpect_issue669',
+                    log_level = self.LOG_WARNING)
 
-            self.name = LinuxDevice.cmd(self, "hostname", log_level = self.LOG_CRIT).strip()
+            self.name = LinuxDevice.cmd(self, "hostname", log_level = self.LOG_WARNING).strip()
             if self.name:
                 self["name"] = self["name"] and self["name"] or self.name.split('.')[0]
             else:
@@ -236,6 +236,7 @@ class LinuxDevice(object):
             sys._getframe().f_code.co_name,
             self.version,
             time.time() - self.start_time))
+        self.cmd('rm $INPUTRC', log_level = self.LOG_WARNING)
         #self.psession.close(force=True)
 
     def login(self, terminal_type = 'ansi', login_timeout = 10):
