@@ -1,5 +1,4 @@
 #!/usr/bin/env python3
-
 from netdevice import linux
 import simplejson as json
 import pexpect
@@ -66,17 +65,12 @@ class OvsHost(linux.LinuxDevice):
         Get the trace file.
         Don't stop the OVS or docker.
         '''
-        # postconfig
-        self.log("%s.%s(%s), finish in %.2f seconds\n" %(self.__class__.__name__,
-            sys._getframe().f_code.co_name,
-            self.version,
-            time.time() - self.start_time))
-
         if (self["vlog"] >= 0):
             #self.get_file('/usr/local/var/log/openvswitch/ovsdb-server.log',
             #        "%s_ovsdb-server.log" %(self["name"]))
             self.get_file('/usr/local/var/log/openvswitch/ovs-vswitchd.log',
                     "%s_ovs-vswitched.log" %(self["name"]))
+        linux.LinuxDevice.__del__(self)
 
     def add_br (self, name, *args, **kwargs):
         '''
@@ -175,8 +169,9 @@ class OvsHost(linux.LinuxDevice):
                 # be compatible with the old version.
                 arg["mac"] = macaddr.split()[1]
                 arg["ofport"] = self.ovs_get_container_ofport(arg["name"])
-            elif dtype == "qemu-system-x86_64":
-                self.__add_vm(**arg)
+            elif dtype == "vm":
+                self.__add_vm(bridge_name, **arg)
+                arg["ofport"] = self.ovs_get_interface("to_%s" %(arg["name"]), "ofport")
             else:
                 self.log("device type %s is not supported now..." %(dtype))
 
@@ -191,12 +186,9 @@ class OvsHost(linux.LinuxDevice):
 
     def __add_container (self, bridge_name,
             name = "con1",
-            type = "docker",
             host_dir = "/var/shared",
             container_dir = "/var/shared", 
             interface = "eth1",
-            ip = "",
-            vlan = None,
             **kwargs):
         '''
         Create a container and connect it to the bridge: bridge_name.
@@ -205,15 +197,37 @@ class OvsHost(linux.LinuxDevice):
         self.cmd('docker run --privileged -d --name %s --net=none -v %s:%s -it centos'
                 %(name, host_dir, container_dir))
         #self.cmd(' docker exec -it con11 rpm -ivh /var/shared/tcpdump-4.9.3-1.el8.x86_64.rpm ')
-        self.cmd('ovs-docker add-port %s %s %s --ipaddress=%s'
-                %(bridge_name, interface, name, ip))
+
+
+        cmd = 'ovs-docker add-port %s %s %s' %(bridge_name, interface, name)
+        if (kwargs.get("ip", None)):
+            cmd += " --ipaddress=%s" %(kwargs["ip"])
+        if (kwargs.get("mac", None)):
+            cmd += " --macaddress=%s" %(kwargs["mac"])
+        if (kwargs.get("gateway", None)):
+            cmd += " --gateway=%s" %(kwargs["gateway"])
+        if (kwargs.get("mtu", None)):
+            cmd += " --mtu=%s" %(kwargs["mtu"])
+        self.cmd(cmd)
 
         # Configure vlan on self-port if the device has vlan configured.
-        if vlan:
+        if (kwargs.get("vlan", None)):
             self.cmd('ovs-vsctl set port %s tag=%d'
-                    %(ovs_get_container_port(bridge_name, name = name), vlan))
+                    %(ovs_get_container_port(bridge_name, name = name),
+                        kwargs["vlan"]))
 
-    def __add_vm (self, mask = None,
+    def __add_vm (self, bridge_name, name, type = "vm", **kwargs):
+        '''
+        '''
+        p = {"name": "to_%s" %(name),
+                "type": "dpdkvhostuserclient",
+                "options:vhost-server-path": kwargs.get("path", None)}
+        self.add_port(bridge_name, **p)
+        if kwargs.get("start_cmd", None):
+            # start the vm if it doesn't auto start
+            self.cmd(kwargs["start_cmd"])
+
+    def __add_vm2 (self, mask = None,
             type = "qemu-system-x86_64",
             name = "vm1",
             cpu = "host", 
